package com.muyu.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.domain.mysql.BaseConfig;
import com.muyu.domain.mysql.config.MysqlPoolConfig;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@EqualsAndHashCode(callSuper = true)
@TableName(value ="source",autoResultMap = true) //数据库表相关
public class Source extends BaseEntity {
    /** 主键 */

    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /** 接入源名称 */
    @Excel(name = "接入源名称")
    @NotBlank
    private String dataResourceName;

    /** 数据来源系统名称 */
    @Excel(name = "数据来源系统名称")
    @NotBlank
    private String dataSourcesSystemName;

    /** 主机ip地址 */
    @NotNull
    @Excel(name = "主机ip地址")
    private String host;

    /** 端口 */
    @Excel(name = "端口")
    private String port;


    /** 数据接入类型 */
    @Excel(name = "数据接入类型")
    private String databaseType;

    /** 数据库名称 */
    @Excel(name = "数据库名称")
    private String databaseName;

    /** 初始化连接数量 */
    @Excel(name = "初始化连接数量")
    private Long initLinkNum;

    /** 最大连接数量 */
    @Excel(name = "最大连接数量")
    private Long maxLinkNum;

    /** 最大等待时间 */
    @Excel(name = "最大等待时间")
    private Long maxWaitTime;

    /** 最大等待次数 */
    @Excel(name = "最大等待次数")
    private Long maxWaitTimes;

    @Excel(name ="连接参数")
    private String connectionParams;

    @Excel(name ="用户名")
    private String username;

    @Excel(name ="密码")
    private String password;

    @Excel(name ="备注")
    private String remark;

    @Excel(name ="状态")
    private String status;

    @Excel(name = "驱动 ")
    private String driverName;

    public static MysqlPoolConfig  getMysqlPoolConfig(Source source) {
      return   MysqlPoolConfig.builder()
                .id(source.getId())
                .dataResourceName(source.getDataResourceName())
                .dataSourcesSystemName(source.getDataSourcesSystemName())
                .host(source.getHost())
                .port(source.getPort())
                .databaseType(source.getDatabaseType())
                .databaseName(source.getDatabaseName())
                .initLinkNum(source.getInitLinkNum())
                .maxLinkNum(source.getMaxLinkNum())
                .build();
    }


    public   String getUrl(){
        StringBuilder urlSb = new StringBuilder(BaseConfig.MYSQLJDBCPRO);
        urlSb.append(this.host);
        urlSb.append(":");
        urlSb.append(this.port);
        urlSb.append("/");
        urlSb.append(this.databaseName);
//        urlSb.append("?");
//        urlSb.append(this.connectionParams);
        return urlSb.toString();
    }



}
