package com.muyu.cloud.etl.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.dtflys.forest.annotation.NotNull;
import com.muyu.cloud.etl.service.AccreditService;
import com.muyu.cloud.etl.service.StructureService;
import com.muyu.cloud.etl.service.TableInfoService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysUser;
import com.muyu.domain.Structure;
import com.muyu.domain.TableInfo;
import com.muyu.domain.rep.TableInfoResp;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashSet;
import java.util.List;

@RestController
@RequestMapping("/tableInfo")
public class TableInfoController {

    @Autowired
    private TableInfoService tableInfoService;
    @Autowired
    private StructureService structureService;
    //添加授权和修改授权
    @Autowired
    private AccreditService accreditService;

    //查询所有的数据进行
    @GetMapping("/findTableInfoList")
    public Result findByTableName() {
        List<TableInfo> list = tableInfoService.list();
        List<TableInfoResp> respList = list.stream().filter(tableInfo -> tableInfo.getParentId()==0).map(tableInfo -> {
            TableInfoResp tableInfoResp = TableInfo.toTableInfoResp(tableInfo);
            tableInfoResp.setChildren(getChildren(tableInfo, list));
            return tableInfoResp;
        }).toList();
        return Result.success(respList);
    }

    @NotNull
    private static List<TableInfoResp> getChildren(TableInfo tableInfo, List<TableInfo> list) {
        return list.stream().filter(tableInfo1 -> tableInfo1.getParentId().equals(tableInfo.getId())).map(
                tableInfo2 -> TableInfo.toTableInfoResp(tableInfo2)
        ).toList();
    }


    @GetMapping("/findStruceure/{id}")
    public Result<List<Structure>> findStruceure(@PathVariable("id") Integer id) {
     List<Structure> structureList=   structureService.findStructurelistS(id);
     return Result.success(structureList);
    }


    @GetMapping("/findTableInfoListAccredit")
    public Result findTableInfoListAccredit() {

//        List<TableInfo> list = tableInfoService.findSourceList();

        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser sysUser = loginUser.getSysUser();

        Long userId = sysUser.getUserId();
        Long deptId = sysUser.getDeptId();

        List<Integer> tableIdsUser=accreditService.findUserTableIds(userId);
        List<Integer> tableIdsDept=accreditService.findDeptTableIds(deptId);

        HashSet<TableInfo> tableInfoHashSet = new HashSet<>();

        for (Integer tableId : tableIdsUser) {
            TableInfo tableInfo = tableInfoService.getById(tableId);
            tableInfoHashSet.add(tableInfo);
            if(tableInfo.getParentId()!=0){
                LambdaQueryWrapper<TableInfo> tableInfoLambdaQueryWrapper = new LambdaQueryWrapper<>();
                tableInfoLambdaQueryWrapper.eq(TableInfo::getId,tableInfo.getParentId());
                TableInfo tableInfo1 = tableInfoService.getOne(tableInfoLambdaQueryWrapper);
                tableInfoHashSet.add(tableInfo1);
            }
            if(tableInfo.getParentId()==0){
                Long id = tableInfo.getId();
                LambdaQueryWrapper<TableInfo> tableInfoLambdaQueryWrapper = new LambdaQueryWrapper<>();
                tableInfoLambdaQueryWrapper.eq(TableInfo::getParentId,id);
                List<TableInfo> list1 = tableInfoService.list(tableInfoLambdaQueryWrapper);
                for (TableInfo info : list1) {
                    tableInfoHashSet.add(info);
                }
            }
        }

        for (Integer tableId1 : tableIdsDept) {
            TableInfo tableInfo = tableInfoService.getById(tableId1);
            tableInfoHashSet.add(tableInfo);
            if(tableInfo.getParentId()!=0){
                LambdaQueryWrapper<TableInfo> tableInfoLambdaQueryWrapper = new LambdaQueryWrapper<>();
                tableInfoLambdaQueryWrapper.eq(TableInfo::getId,tableInfo.getParentId());
                TableInfo tableInfo1 = tableInfoService.getOne(tableInfoLambdaQueryWrapper);
                tableInfoHashSet.add(tableInfo1);
            }
            if(tableInfo.getParentId()==0){
                Long id = tableInfo.getId();
                LambdaQueryWrapper<TableInfo> tableInfoLambdaQueryWrapper = new LambdaQueryWrapper<>();
                tableInfoLambdaQueryWrapper.eq(TableInfo::getParentId,id);
                List<TableInfo> list1 = tableInfoService.list(tableInfoLambdaQueryWrapper);
                for (TableInfo info : list1) {
                    tableInfoHashSet.add(info);
                }
            }
        }


        List<TableInfoResp> tableInfoResps = tableInfoHashSet.stream()
                .filter(tableInfo ->
                        tableInfo.getParentId()== 0).map(tableInfo -> {
                    TableInfoResp tableInfoResp = TableInfo.toTableInfoResp(tableInfo);
                    tableInfoResp.setChildren(getSetChildren(tableInfo, tableInfoHashSet));
                    return tableInfoResp;
                }).toList();

        return Result.success(tableInfoResps);
    }


    @NotNull
    private static List<TableInfoResp> getSetChildren(TableInfo tableInfo, HashSet<TableInfo> tableInfoHashSet) {
        List<TableInfoResp> list = tableInfoHashSet.stream().filter(tableInfo1 -> tableInfo1.getParentId()
                .equals(tableInfo.getId())).map(
                tableInfo2 -> TableInfo.toTableInfoResp(tableInfo2)
        ).toList();
        return list;
    }



}
